# McAfee Active Response (MAR) DXL Python Client Library

This distribution contains following directories:

- doc
  - Documentation for the MAR DXL Python client library
- lib
  - MAR DXL Python client libraries (.zip, .egg, .whl)
- sample
  - Samples that demonstrate use of the MAR DXL Python client library

Click here to view the documentation which includes installation instructions, MAR DXL Python client library details, and samples.